"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.common_config.parameters_pb2
import prodvana.proto.prodvana.convergence.convergence_mode_pb2
import prodvana.proto.prodvana.insights.insights_pb2
import prodvana.proto.prodvana.metrics.metrics_pb2
import prodvana.proto.prodvana.repo.repo_pb2
import prodvana.proto.prodvana.service.object_pb2
import prodvana.proto.prodvana.service.parameters_pb2
import prodvana.proto.prodvana.service.service_config_pb2
import prodvana.proto.prodvana.service.user_metadata_pb2
import prodvana.proto.prodvana.stat.efficiency_pb2
import prodvana.proto.prodvana.version.source_metadata_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ServiceConfigVersionReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    SERVICE_CONFIG_VERSION_FIELD_NUMBER: builtins.int
    application: builtins.str
    """TODO(naphat) unify with ApplyParametersReq below"""
    service: builtins.str
    service_config_version: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        service_config_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service", "service_config_version", b"service_config_version"]) -> None: ...

global___ServiceConfigVersionReference = ServiceConfigVersionReference

class GenerateVersionNameReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    SERVICE_CONFIG_VERSION_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    PER_RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    service_config_version: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue]: ...
    @property
    def per_release_channel(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplyParametersReq.PerReleaseChannel]: ...
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        service_config_version: builtins.str = ...,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue] | None = ...,
        per_release_channel: collections.abc.Iterable[global___ApplyParametersReq.PerReleaseChannel] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "parameters", b"parameters", "per_release_channel", b"per_release_channel", "service", b"service", "service_config_version", b"service_config_version"]) -> None: ...

global___GenerateVersionNameReq = GenerateVersionNameReq

class GenerateVersionNameResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    def __init__(
        self,
        *,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["version", b"version"]) -> None: ...

global___GenerateVersionNameResp = GenerateVersionNameResp

class ApplyParametersReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class PerReleaseChannel(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
        PARAMETERS_FIELD_NUMBER: builtins.int
        release_channel: builtins.str
        @property
        def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue]:
            """takes precedence over any parameters set at top level"""
        def __init__(
            self,
            *,
            release_channel: builtins.str = ...,
            parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["parameters", b"parameters", "release_channel", b"release_channel"]) -> None: ...

    SERVICE_CONFIG_FIELD_NUMBER: builtins.int
    SERVICE_CONFIG_VERSION_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    PER_RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    TEST_ONLY_SKIP_REGISTRY_CHECK_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    BUNDLE_NAME_OVERRIDE_FIELD_NUMBER: builtins.int
    HANDLE_BUNDLE_NAME_DUPLICATE_FIELD_NUMBER: builtins.int
    SKIP_RUNTIME_VALIDATION_FIELD_NUMBER: builtins.int
    @property
    def service_config(self) -> prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig: ...
    @property
    def service_config_version(self) -> global___ServiceConfigVersionReference: ...
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue]: ...
    @property
    def per_release_channel(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplyParametersReq.PerReleaseChannel]: ...
    test_only_skip_registry_check: builtins.bool
    """skip any kind of attempts to contact container registry, e.g. to check if image exists or get program defaults"""
    application: builtins.str
    """application can be specified here or as part of service config"""
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    bundle_name_override: builtins.str
    handle_bundle_name_duplicate: builtins.bool
    """if the bundle name override exists already, handle duplicate by appending a number"""
    skip_runtime_validation: builtins.bool
    """skip talking to runtimes for validation, can be useful to speed up the validation at the cost of not actually fully validating the config"""
    def __init__(
        self,
        *,
        service_config: prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig | None = ...,
        service_config_version: global___ServiceConfigVersionReference | None = ...,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue] | None = ...,
        per_release_channel: collections.abc.Iterable[global___ApplyParametersReq.PerReleaseChannel] | None = ...,
        test_only_skip_registry_check: builtins.bool = ...,
        application: builtins.str = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
        bundle_name_override: builtins.str = ...,
        handle_bundle_name_duplicate: builtins.bool = ...,
        skip_runtime_validation: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["oneof", b"oneof", "service_config", b"service_config", "service_config_version", b"service_config_version", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "bundle_name_override", b"bundle_name_override", "handle_bundle_name_duplicate", b"handle_bundle_name_duplicate", "oneof", b"oneof", "parameters", b"parameters", "per_release_channel", b"per_release_channel", "service_config", b"service_config", "service_config_version", b"service_config_version", "skip_runtime_validation", b"skip_runtime_validation", "source", b"source", "source_metadata", b"source_metadata", "test_only_skip_registry_check", b"test_only_skip_registry_check"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["oneof", b"oneof"]) -> typing_extensions.Literal["service_config", "service_config_version"] | None: ...

global___ApplyParametersReq = ApplyParametersReq

class ApplyParametersResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    EFFICIENCY_STAT_FIELD_NUMBER: builtins.int
    service_id: builtins.str
    version: builtins.str
    @property
    def efficiency_stat(self) -> prodvana.proto.prodvana.stat.efficiency_pb2.EfficiencyStat:
        """only set if compute_efficiency was set in request"""
    def __init__(
        self,
        *,
        service_id: builtins.str = ...,
        version: builtins.str = ...,
        efficiency_stat: prodvana.proto.prodvana.stat.efficiency_pb2.EfficiencyStat | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["efficiency_stat", b"efficiency_stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["efficiency_stat", b"efficiency_stat", "service_id", b"service_id", "version", b"version"]) -> None: ...

global___ApplyParametersResp = ApplyParametersResp

class ValidateApplyParametersResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    APP_VERSION_FIELD_NUMBER: builtins.int
    COMPILED_SERVICE_INSTANCE_CONFIGS_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig:
        """config as passed in by user"""
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig:
        """config with defaults applied"""
    app_version: builtins.str
    """the app version that is used for validation"""
    @property
    def compiled_service_instance_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.service.service_config_pb2.CompiledServiceInstanceConfig]:
        """compiled config per release channel, with per-release-channel overrides applied"""
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig | None = ...,
        compiled_config: prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig | None = ...,
        app_version: builtins.str = ...,
        compiled_service_instance_configs: collections.abc.Iterable[prodvana.proto.prodvana.service.service_config_pb2.CompiledServiceInstanceConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_version", b"app_version", "compiled_config", b"compiled_config", "compiled_service_instance_configs", b"compiled_service_instance_configs", "config", b"config"]) -> None: ...

global___ValidateApplyParametersResp = ValidateApplyParametersResp

class GetMaterializedConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    service: builtins.str
    version: builtins.str
    """omit to get latest version"""
    application: builtins.str
    def __init__(
        self,
        *,
        service: builtins.str = ...,
        version: builtins.str = ...,
        application: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service", "version", b"version"]) -> None: ...

global___GetMaterializedConfigReq = GetMaterializedConfigReq

class GetMaterializedConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    COMPILED_SERVICE_INSTANCE_CONFIGS_FIELD_NUMBER: builtins.int
    VERSION_METADATA_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig:
        """config as passed in by user"""
    version: builtins.str
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig:
        """config with defaults applied"""
    @property
    def compiled_service_instance_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.service.service_config_pb2.CompiledServiceInstanceConfig]:
        """compiled config per release channel, with per-release-channel overrides applied"""
    @property
    def version_metadata(self) -> global___ListMaterializedConfigVersionsResp.VersionMetadata: ...
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig | None = ...,
        version: builtins.str = ...,
        compiled_config: prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig | None = ...,
        compiled_service_instance_configs: collections.abc.Iterable[prodvana.proto.prodvana.service.service_config_pb2.CompiledServiceInstanceConfig] | None = ...,
        version_metadata: global___ListMaterializedConfigVersionsResp.VersionMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "config", b"config", "version_metadata", b"version_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "compiled_service_instance_configs", b"compiled_service_instance_configs", "config", b"config", "version", b"version", "version_metadata", b"version_metadata"]) -> None: ...

global___GetMaterializedConfigResp = GetMaterializedConfigResp

class DeleteServiceReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    service: builtins.str
    application: builtins.str
    def __init__(
        self,
        *,
        service: builtins.str = ...,
        application: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service"]) -> None: ...

global___DeleteServiceReq = DeleteServiceReq

class DeleteServiceResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteServiceResp = DeleteServiceResp

class ListServicesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    DETAILED_FIELD_NUMBER: builtins.int
    application: builtins.str
    detailed: builtins.bool
    """if not set, only meta without version is returned"""
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        detailed: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "detailed", b"detailed"]) -> None: ...

global___ListServicesReq = ListServicesReq

class ListServicesResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICES_FIELD_NUMBER: builtins.int
    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.service.object_pb2.Service]: ...
    def __init__(
        self,
        *,
        services: collections.abc.Iterable[prodvana.proto.prodvana.service.object_pb2.Service] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["services", b"services"]) -> None: ...

global___ListServicesResp = ListServicesResp

class GetServiceReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service"]) -> None: ...

global___GetServiceReq = GetServiceReq

class GetServiceResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FIELD_NUMBER: builtins.int
    @property
    def service(self) -> prodvana.proto.prodvana.service.object_pb2.Service: ...
    def __init__(
        self,
        *,
        service: prodvana.proto.prodvana.service.object_pb2.Service | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["service", b"service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["service", b"service"]) -> None: ...

global___GetServiceResp = GetServiceResp

class ListServiceInstancesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service"]) -> None: ...

global___ListServiceInstancesReq = ListServiceInstancesReq

class ListServiceInstancesResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_INSTANCES_FIELD_NUMBER: builtins.int
    @property
    def service_instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.service.object_pb2.ServiceInstance]: ...
    def __init__(
        self,
        *,
        service_instances: collections.abc.Iterable[prodvana.proto.prodvana.service.object_pb2.ServiceInstance] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service_instances", b"service_instances"]) -> None: ...

global___ListServiceInstancesResp = ListServiceInstancesResp

class GetServiceInstanceReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    release_channel: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        release_channel: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "release_channel", b"release_channel", "service", b"service"]) -> None: ...

global___GetServiceInstanceReq = GetServiceInstanceReq

class GetServiceInstanceResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_INSTANCE_FIELD_NUMBER: builtins.int
    @property
    def service_instance(self) -> prodvana.proto.prodvana.service.object_pb2.ServiceInstance: ...
    def __init__(
        self,
        *,
        service_instance: prodvana.proto.prodvana.service.object_pb2.ServiceInstance | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["service_instance", b"service_instance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["service_instance", b"service_instance"]) -> None: ...

global___GetServiceInstanceResp = GetServiceInstanceResp

class GetServiceMetricsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    START_TIMESTAMP_FIELD_NUMBER: builtins.int
    END_TIMESTAMP_FIELD_NUMBER: builtins.int
    INCLUDE_COST_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    @property
    def start_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def end_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    include_cost: builtins.bool
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        start_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        include_cost: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_timestamp", b"end_timestamp", "start_timestamp", b"start_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "end_timestamp", b"end_timestamp", "include_cost", b"include_cost", "service", b"service", "start_timestamp", b"start_timestamp"]) -> None: ...

global___GetServiceMetricsReq = GetServiceMetricsReq

class GetServiceMetricsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_METRICS_FIELD_NUMBER: builtins.int
    COST_FIELD_NUMBER: builtins.int
    @property
    def deployment_metrics(self) -> prodvana.proto.prodvana.metrics.metrics_pb2.DeploymentMetrics: ...
    @property
    def cost(self) -> prodvana.proto.prodvana.metrics.metrics_pb2.Cost: ...
    def __init__(
        self,
        *,
        deployment_metrics: prodvana.proto.prodvana.metrics.metrics_pb2.DeploymentMetrics | None = ...,
        cost: prodvana.proto.prodvana.metrics.metrics_pb2.Cost | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cost", b"cost", "deployment_metrics", b"deployment_metrics"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cost", b"cost", "deployment_metrics", b"deployment_metrics"]) -> None: ...

global___GetServiceMetricsResp = GetServiceMetricsResp

class GetServiceInsightsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service"]) -> None: ...

global___GetServiceInsightsReq = GetServiceInsightsReq

class ListCommitsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "page_size", b"page_size", "page_token", b"page_token", "service", b"service"]) -> None: ...

global___ListCommitsReq = ListCommitsReq

class ListCommitsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMITS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def commits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.repo.repo_pb2.Commit]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        commits: collections.abc.Iterable[prodvana.proto.prodvana.repo.repo_pb2.Commit] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["commits", b"commits", "next_page_token", b"next_page_token"]) -> None: ...

global___ListCommitsResp = ListCommitsResp

class GetServiceInsightsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSIGHTS_FIELD_NUMBER: builtins.int
    @property
    def insights(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.insights.insights_pb2.Insight]: ...
    def __init__(
        self,
        *,
        insights: collections.abc.Iterable[prodvana.proto.prodvana.insights.insights_pb2.Insight] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["insights", b"insights"]) -> None: ...

global___GetServiceInsightsResp = GetServiceInsightsResp

class SnoozeServiceInsightReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    CLASS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "class", b"class", "duration", b"duration", "service", b"service"]) -> None: ...

global___SnoozeServiceInsightReq = SnoozeServiceInsightReq

class SnoozeServiceInsightResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SnoozeServiceInsightResp = SnoozeServiceInsightResp

class GetServiceMetadataReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service"]) -> None: ...

global___GetServiceMetadataReq = GetServiceMetadataReq

class GetServiceMetadataResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> prodvana.proto.prodvana.service.user_metadata_pb2.ServiceUserMetadata:
        """metadata with no variables substitution, no modifications from parents"""
    def __init__(
        self,
        *,
        metadata: prodvana.proto.prodvana.service.user_metadata_pb2.ServiceUserMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> None: ...

global___GetServiceMetadataResp = GetServiceMetadataResp

class SetServiceMetadataReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    @property
    def metadata(self) -> prodvana.proto.prodvana.service.user_metadata_pb2.ServiceUserMetadata: ...
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        metadata: prodvana.proto.prodvana.service.user_metadata_pb2.ServiceUserMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "metadata", b"metadata", "service", b"service"]) -> None: ...

global___SetServiceMetadataReq = SetServiceMetadataReq

class SetServiceMetadataResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetServiceMetadataResp = SetServiceMetadataResp

class SetServiceConvergenceModeReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    CONVERGENCE_MODE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    convergence_mode: prodvana.proto.prodvana.convergence.convergence_mode_pb2.ConvergenceMode.ValueType
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        convergence_mode: prodvana.proto.prodvana.convergence.convergence_mode_pb2.ConvergenceMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "convergence_mode", b"convergence_mode", "service", b"service"]) -> None: ...

global___SetServiceConvergenceModeReq = SetServiceConvergenceModeReq

class SetServiceConvergenceModeResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetServiceConvergenceModeResp = SetServiceConvergenceModeResp

class ListMaterializedConfigVersionsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "page_size", b"page_size", "page_token", b"page_token", "service", b"service"]) -> None: ...

global___ListMaterializedConfigVersionsReq = ListMaterializedConfigVersionsReq

class ListMaterializedConfigVersionsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class VersionMetadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VERSION_FIELD_NUMBER: builtins.int
        CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
        CONFIG_VERSION_FIELD_NUMBER: builtins.int
        PARAMETERS_FIELD_NUMBER: builtins.int
        PARAMETER_VALUES_FIELD_NUMBER: builtins.int
        SOURCE_FIELD_NUMBER: builtins.int
        SOURCE_METADATA_FIELD_NUMBER: builtins.int
        version: builtins.str
        @property
        def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        config_version: builtins.str
        @property
        def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition]: ...
        @property
        def parameter_values(self) -> prodvana.proto.prodvana.service.parameters_pb2.ServiceParameterValues: ...
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
        @property
        def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
        def __init__(
            self,
            *,
            version: builtins.str = ...,
            creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            config_version: builtins.str = ...,
            parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition] | None = ...,
            parameter_values: prodvana.proto.prodvana.service.parameters_pb2.ServiceParameterValues | None = ...,
            source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
            source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "parameter_values", b"parameter_values", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["config_version", b"config_version", "creation_timestamp", b"creation_timestamp", "parameter_values", b"parameter_values", "parameters", b"parameters", "source", b"source", "source_metadata", b"source_metadata", "version", b"version"]) -> None: ...

    VERSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListMaterializedConfigVersionsResp.VersionMetadata]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        versions: collections.abc.Iterable[global___ListMaterializedConfigVersionsResp.VersionMetadata] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "versions", b"versions"]) -> None: ...

global___ListMaterializedConfigVersionsResp = ListMaterializedConfigVersionsResp

class ConfigureServiceReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_CONFIG_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    BUNDLE_NAME_OVERRIDE_FIELD_NUMBER: builtins.int
    SKIP_RUNTIME_VALIDATION_FIELD_NUMBER: builtins.int
    application: builtins.str
    @property
    def service_config(self) -> prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig: ...
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    bundle_name_override: builtins.str
    skip_runtime_validation: builtins.bool
    """skip talking to runtimes for validation, can be useful to speed up the validation at the cost of not actually fully validating the config"""
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service_config: prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig | None = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
        bundle_name_override: builtins.str = ...,
        skip_runtime_validation: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["service_config", b"service_config", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "bundle_name_override", b"bundle_name_override", "service_config", b"service_config", "skip_runtime_validation", b"skip_runtime_validation", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___ConfigureServiceReq = ConfigureServiceReq

class ConfigureServiceResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ID_FIELD_NUMBER: builtins.int
    CONFIG_VERSION_FIELD_NUMBER: builtins.int
    service_id: builtins.str
    config_version: builtins.str
    def __init__(
        self,
        *,
        service_id: builtins.str = ...,
        config_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_version", b"config_version", "service_id", b"service_id"]) -> None: ...

global___ConfigureServiceResp = ConfigureServiceResp

class ValidateConfigureServiceResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_CONFIG_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def input_config(self) -> prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig:
        """config as passed in by user"""
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig:
        """config with defaults applied"""
    def __init__(
        self,
        *,
        input_config: prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig | None = ...,
        compiled_config: prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config"]) -> None: ...

global___ValidateConfigureServiceResp = ValidateConfigureServiceResp

class ListServiceConfigVersionsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "page_size", b"page_size", "page_token", b"page_token", "service", b"service"]) -> None: ...

global___ListServiceConfigVersionsReq = ListServiceConfigVersionsReq

class ListServiceConfigVersionsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class VersionMetadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VERSION_FIELD_NUMBER: builtins.int
        CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
        SOURCE_FIELD_NUMBER: builtins.int
        SOURCE_METADATA_FIELD_NUMBER: builtins.int
        version: builtins.str
        @property
        def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
        @property
        def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
        def __init__(
            self,
            *,
            version: builtins.str = ...,
            creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
            source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "source", b"source", "source_metadata", b"source_metadata", "version", b"version"]) -> None: ...

    VERSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListServiceConfigVersionsResp.VersionMetadata]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        versions: collections.abc.Iterable[global___ListServiceConfigVersionsResp.VersionMetadata] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "versions", b"versions"]) -> None: ...

global___ListServiceConfigVersionsResp = ListServiceConfigVersionsResp

class GetServiceConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    CONFIG_VERSION_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    config_version: builtins.str
    """omit to get latest"""
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        config_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "config_version", b"config_version", "service", b"service"]) -> None: ...

global___GetServiceConfigReq = GetServiceConfigReq

class GetServiceConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    INPUT_CONFIG_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    CONFIG_VERSION_FIELD_NUMBER: builtins.int
    CONFIG_VERSION_METADATA_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig:
        """deprecated, same as compiled_config"""
    @property
    def input_config(self) -> prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig:
        """may be null because input config wasn't stored before 2023-09-25"""
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig: ...
    config_version: builtins.str
    """deprecated, use config_version_metadata"""
    @property
    def config_version_metadata(self) -> global___ListServiceConfigVersionsResp.VersionMetadata:
        """next tag: 6"""
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig | None = ...,
        input_config: prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig | None = ...,
        compiled_config: prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig | None = ...,
        config_version: builtins.str = ...,
        config_version_metadata: global___ListServiceConfigVersionsResp.VersionMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "config", b"config", "config_version_metadata", b"config_version_metadata", "input_config", b"input_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "config", b"config", "config_version", b"config_version", "config_version_metadata", b"config_version_metadata", "input_config", b"input_config"]) -> None: ...

global___GetServiceConfigResp = GetServiceConfigResp



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.config_writeback.writeback_pb2
import prodvana.proto.prodvana.insights.insights_pb2
import prodvana.proto.prodvana.metrics.metrics_pb2
import prodvana.proto.prodvana.organization.user_metadata_pb2
import prodvana.proto.prodvana.users.users_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class OrganizationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    WRITEBACK_CONFIG_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    USER_METADATA_FIELD_NUMBER: builtins.int
    id: builtins.str
    display_name: builtins.str
    @property
    def writeback_config(self) -> prodvana.proto.prodvana.config_writeback.writeback_pb2.ConfigWritebackPath: ...
    slug: builtins.str
    @property
    def user_metadata(self) -> prodvana.proto.prodvana.organization.user_metadata_pb2.OrganizationUserMetadata: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        display_name: builtins.str = ...,
        writeback_config: prodvana.proto.prodvana.config_writeback.writeback_pb2.ConfigWritebackPath | None = ...,
        slug: builtins.str = ...,
        user_metadata: prodvana.proto.prodvana.organization.user_metadata_pb2.OrganizationUserMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user_metadata", b"user_metadata", "writeback_config", b"writeback_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "id", b"id", "slug", b"slug", "user_metadata", b"user_metadata", "writeback_config", b"writeback_config"]) -> None: ...

global___OrganizationInfo = OrganizationInfo

class GetOrganizationReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetOrganizationReq = GetOrganizationReq

class GetOrganizationResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_FIELD_NUMBER: builtins.int
    @property
    def organization(self) -> global___OrganizationInfo: ...
    def __init__(
        self,
        *,
        organization: global___OrganizationInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["organization", b"organization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["organization", b"organization"]) -> None: ...

global___GetOrganizationResp = GetOrganizationResp

class GetOrganizationMetricsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIMESTAMP_FIELD_NUMBER: builtins.int
    END_TIMESTAMP_FIELD_NUMBER: builtins.int
    @property
    def start_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def end_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        start_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_timestamp", b"end_timestamp", "start_timestamp", b"start_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_timestamp", b"end_timestamp", "start_timestamp", b"start_timestamp"]) -> None: ...

global___GetOrganizationMetricsReq = GetOrganizationMetricsReq

class GetOrganizationMetricsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_METRICS_FIELD_NUMBER: builtins.int
    @property
    def deployment_metrics(self) -> prodvana.proto.prodvana.metrics.metrics_pb2.DeploymentMetrics: ...
    def __init__(
        self,
        *,
        deployment_metrics: prodvana.proto.prodvana.metrics.metrics_pb2.DeploymentMetrics | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deployment_metrics", b"deployment_metrics"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_metrics", b"deployment_metrics"]) -> None: ...

global___GetOrganizationMetricsResp = GetOrganizationMetricsResp

class GetOrganizationInsightsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetOrganizationInsightsReq = GetOrganizationInsightsReq

class GetOrganizationInsightsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSIGHTS_FIELD_NUMBER: builtins.int
    @property
    def insights(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.insights.insights_pb2.Insight]: ...
    def __init__(
        self,
        *,
        insights: collections.abc.Iterable[prodvana.proto.prodvana.insights.insights_pb2.Insight] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["insights", b"insights"]) -> None: ...

global___GetOrganizationInsightsResp = GetOrganizationInsightsResp

class SnoozeOrganizationInsightReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLASS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["class", b"class", "duration", b"duration"]) -> None: ...

global___SnoozeOrganizationInsightReq = SnoozeOrganizationInsightReq

class SnoozeOrganizationInsightResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SnoozeOrganizationInsightResp = SnoozeOrganizationInsightResp

class GetOrganizationMetadataReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetOrganizationMetadataReq = GetOrganizationMetadataReq

class GetOrganizationMetadataResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> prodvana.proto.prodvana.organization.user_metadata_pb2.OrganizationUserMetadata:
        """metadata with no variables substitution, no modifications from parents"""
    def __init__(
        self,
        *,
        metadata: prodvana.proto.prodvana.organization.user_metadata_pb2.OrganizationUserMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> None: ...

global___GetOrganizationMetadataResp = GetOrganizationMetadataResp

class SetOrganizationMetadataReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> prodvana.proto.prodvana.organization.user_metadata_pb2.OrganizationUserMetadata: ...
    def __init__(
        self,
        *,
        metadata: prodvana.proto.prodvana.organization.user_metadata_pb2.OrganizationUserMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> None: ...

global___SetOrganizationMetadataReq = SetOrganizationMetadataReq

class SetOrganizationMetadataResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetOrganizationMetadataResp = SetOrganizationMetadataResp

class GetUserReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_id", b"user_id"]) -> None: ...

global___GetUserReq = GetUserReq

class GetUserResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> prodvana.proto.prodvana.users.users_pb2.User: ...
    def __init__(
        self,
        *,
        user: prodvana.proto.prodvana.users.users_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["user", b"user"]) -> None: ...

global___GetUserResp = GetUserResp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/application/application_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.application import application_config_pb2 as prodvana_dot_application_dot_application__config__pb2
from prodvana.proto.prodvana.application import object_pb2 as prodvana_dot_application_dot_object__pb2
from prodvana.proto.prodvana.application import user_metadata_pb2 as prodvana_dot_application_dot_user__metadata__pb2
from prodvana.proto.prodvana.common_config import dangerous_action_pb2 as prodvana_dot_common__config_dot_dangerous__action__pb2
from prodvana.proto.prodvana.metrics import metrics_pb2 as prodvana_dot_metrics_dot_metrics__pb2
from prodvana.proto.prodvana.insights import insights_pb2 as prodvana_dot_insights_dot_insights__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.prodvana/application/application_manager.proto\x12\x14prodvana.application\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a-prodvana/application/application_config.proto\x1a!prodvana/application/object.proto\x1a(prodvana/application/user_metadata.proto\x1a-prodvana/common_config/dangerous_action.proto\x1a\x1eprodvana/metrics/metrics.proto\x1a prodvana/insights/insights.proto\x1a\x1aprodvana/object/meta.proto\x1a&prodvana/version/source_metadata.proto\x1a\x17validate/validate.proto\"\'\n\x13ListApplicationsReq\x12\x10\n\x08\x64\x65tailed\x18\x01 \x01(\x08\"O\n\x14ListApplicationsResp\x12\x37\n\x0c\x61pplications\x18\x01 \x03(\x0b\x32!.prodvana.application.Application\"1\n\x11GetApplicationReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"L\n\x12GetApplicationResp\x12\x36\n\x0b\x61pplication\x18\x01 \x01(\x0b\x32!.prodvana.application.Application\"\x8a\x02\n\x17\x43onfigureApplicationReq\x12M\n\x12\x61pplication_config\x18\x01 \x01(\x0b\x32\'.prodvana.application.ApplicationConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12%\n\x1d\x61pproved_dangerous_action_ids\x18\x02 \x03(\t\x12(\n\x06source\x18\x03 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x04 \x01(\x0b\x32 .prodvana.version.SourceMetadata\x12\x14\n\x0c\x62\x61se_version\x18\x05 \x01(\t\"E\n\x18\x43onfigureApplicationResp\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\"\xe1\x01\n ValidateConfigureApplicationResp\x12\x37\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\'.prodvana.application.ApplicationConfig\x12@\n\x0f\x63ompiled_config\x18\x02 \x01(\x0b\x32\'.prodvana.application.ApplicationConfig\x12\x42\n\x11\x64\x61ngerous_actions\x18\x03 \x03(\x0b\x32\'.prodvana.common_config.DangerousAction\"H\n\x17GetApplicationConfigReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x07version\x18\x02 \x01(\t\"\xa6\x01\n\x18GetApplicationConfigResp\x12\x37\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\'.prodvana.application.ApplicationConfig\x12\x0f\n\x07version\x18\x02 \x01(\t\x12@\n\x0f\x63ompiled_config\x18\x03 \x01(\x0b\x32\'.prodvana.application.ApplicationConfig\"4\n\x14\x44\x65leteApplicationReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x17\n\x15\x44\x65leteApplicationResp\"\xa0\x01\n\x18GetApplicationMetricsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x33\n\x0fstart_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\\\n\x19GetApplicationMetricsResp\x12?\n\x12\x64\x65ployment_metrics\x18\x01 \x01(\x0b\x32#.prodvana.metrics.DeploymentMetrics\"9\n\x19GetApplicationInsightsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"J\n\x1aGetApplicationInsightsResp\x12,\n\x08insights\x18\x01 \x03(\x0b\x32\x1a.prodvana.insights.Insight\"\xa7\x01\n\x1bSnoozeApplicationInsightReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x31\n\x05\x63lass\x18\x02 \x01(\x0e\x32\x18.prodvana.insights.ClassB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x37\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\"\x1e\n\x1cSnoozeApplicationInsightResp\"9\n\x19GetApplicationMetadataReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"]\n\x1aGetApplicationMetadataResp\x12?\n\x08metadata\x18\x01 \x01(\x0b\x32-.prodvana.application.ApplicationUserMetadata\"\x84\x01\n\x19SetApplicationMetadataReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12I\n\x08metadata\x18\x02 \x01(\x0b\x32-.prodvana.application.ApplicationUserMetadataB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x1c\n\x1aSetApplicationMetadataResp2\xbe\x0e\n\x12\x41pplicationManager\x12\x9c\x01\n\x14\x43onfigureApplication\x12-.prodvana.application.ConfigureApplicationReq\x1a..prodvana.application.ConfigureApplicationResp\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/applications/configure:\x01*\x12\xb5\x01\n\x1cValidateConfigureApplication\x12-.prodvana.application.ConfigureApplicationReq\x1a\x36.prodvana.application.ValidateConfigureApplicationResp\".\x82\xd3\xe4\x93\x02(\"#/v1/applications/configure/validate:\x01*\x12\x83\x01\n\x10ListApplications\x12).prodvana.application.ListApplicationsReq\x1a*.prodvana.application.ListApplicationsResp\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/applications\x12\xa6\x01\n\x14GetApplicationConfig\x12-.prodvana.application.GetApplicationConfigReq\x1a..prodvana.application.GetApplicationConfigResp\"/\x82\xd3\xe4\x93\x02)\x12\'/v1/applications/{application=*}/config\x12\x8d\x01\n\x0eGetApplication\x12\'.prodvana.application.GetApplicationReq\x1a(.prodvana.application.GetApplicationResp\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/applications/{application=*}\x12\x90\x01\n\x11\x44\x65leteApplication\x12*.prodvana.application.DeleteApplicationReq\x1a+.prodvana.application.DeleteApplicationResp\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/{application=*}/delete\x12\xaa\x01\n\x15GetApplicationMetrics\x12..prodvana.application.GetApplicationMetricsReq\x1a/.prodvana.application.GetApplicationMetricsResp\"0\x82\xd3\xe4\x93\x02*\x12(/v1/applications/{application=*}/metrics\x12\xae\x01\n\x16GetApplicationInsights\x12/.prodvana.application.GetApplicationInsightsReq\x1a\x30.prodvana.application.GetApplicationInsightsResp\"1\x82\xd3\xe4\x93\x02+\x12)/v1/applications/{application=*}/insights\x12\xbb\x01\n\x18SnoozeApplicationInsight\x12\x31.prodvana.application.SnoozeApplicationInsightReq\x1a\x32.prodvana.application.SnoozeApplicationInsightResp\"8\x82\xd3\xe4\x93\x02\x32\x1a\x30/v1/applications/{application=*}/insights/snooze\x12\xae\x01\n\x16GetApplicationMetadata\x12/.prodvana.application.GetApplicationMetadataReq\x1a\x30.prodvana.application.GetApplicationMetadataResp\"1\x82\xd3\xe4\x93\x02+\x12)/v1/applications/{application=*}/metadata\x12\xb1\x01\n\x16SetApplicationMetadata\x12/.prodvana.application.SetApplicationMetadataReq\x1a\x30.prodvana.application.SetApplicationMetadataResp\"4\x82\xd3\xe4\x93\x02.\")/v1/applications/{application=*}/metadata:\x01*BPZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/applicationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.application.application_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/application'
  _GETAPPLICATIONREQ.fields_by_name['application']._options = None
  _GETAPPLICATIONREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _CONFIGUREAPPLICATIONREQ.fields_by_name['application_config']._options = None
  _CONFIGUREAPPLICATIONREQ.fields_by_name['application_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETAPPLICATIONCONFIGREQ.fields_by_name['application']._options = None
  _GETAPPLICATIONCONFIGREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _DELETEAPPLICATIONREQ.fields_by_name['application']._options = None
  _DELETEAPPLICATIONREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETAPPLICATIONMETRICSREQ.fields_by_name['application']._options = None
  _GETAPPLICATIONMETRICSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETAPPLICATIONINSIGHTSREQ.fields_by_name['application']._options = None
  _GETAPPLICATIONINSIGHTSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _SNOOZEAPPLICATIONINSIGHTREQ.fields_by_name['application']._options = None
  _SNOOZEAPPLICATIONINSIGHTREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _SNOOZEAPPLICATIONINSIGHTREQ.fields_by_name['class']._options = None
  _SNOOZEAPPLICATIONINSIGHTREQ.fields_by_name['class']._serialized_options = b'\372B\005\202\001\002\020\001'
  _SNOOZEAPPLICATIONINSIGHTREQ.fields_by_name['duration']._options = None
  _SNOOZEAPPLICATIONINSIGHTREQ.fields_by_name['duration']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _GETAPPLICATIONMETADATAREQ.fields_by_name['application']._options = None
  _GETAPPLICATIONMETADATAREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _SETAPPLICATIONMETADATAREQ.fields_by_name['application']._options = None
  _SETAPPLICATIONMETADATAREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _SETAPPLICATIONMETADATAREQ.fields_by_name['metadata']._options = None
  _SETAPPLICATIONMETADATAREQ.fields_by_name['metadata']._serialized_options = b'\372B\005\212\001\002\020\001'
  _APPLICATIONMANAGER.methods_by_name['ConfigureApplication']._options = None
  _APPLICATIONMANAGER.methods_by_name['ConfigureApplication']._serialized_options = b'\202\323\344\223\002\037\"\032/v1/applications/configure:\001*'
  _APPLICATIONMANAGER.methods_by_name['ValidateConfigureApplication']._options = None
  _APPLICATIONMANAGER.methods_by_name['ValidateConfigureApplication']._serialized_options = b'\202\323\344\223\002(\"#/v1/applications/configure/validate:\001*'
  _APPLICATIONMANAGER.methods_by_name['ListApplications']._options = None
  _APPLICATIONMANAGER.methods_by_name['ListApplications']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/applications'
  _APPLICATIONMANAGER.methods_by_name['GetApplicationConfig']._options = None
  _APPLICATIONMANAGER.methods_by_name['GetApplicationConfig']._serialized_options = b'\202\323\344\223\002)\022\'/v1/applications/{application=*}/config'
  _APPLICATIONMANAGER.methods_by_name['GetApplication']._options = None
  _APPLICATIONMANAGER.methods_by_name['GetApplication']._serialized_options = b'\202\323\344\223\002\"\022 /v1/applications/{application=*}'
  _APPLICATIONMANAGER.methods_by_name['DeleteApplication']._options = None
  _APPLICATIONMANAGER.methods_by_name['DeleteApplication']._serialized_options = b'\202\323\344\223\002\034*\032/v1/{application=*}/delete'
  _APPLICATIONMANAGER.methods_by_name['GetApplicationMetrics']._options = None
  _APPLICATIONMANAGER.methods_by_name['GetApplicationMetrics']._serialized_options = b'\202\323\344\223\002*\022(/v1/applications/{application=*}/metrics'
  _APPLICATIONMANAGER.methods_by_name['GetApplicationInsights']._options = None
  _APPLICATIONMANAGER.methods_by_name['GetApplicationInsights']._serialized_options = b'\202\323\344\223\002+\022)/v1/applications/{application=*}/insights'
  _APPLICATIONMANAGER.methods_by_name['SnoozeApplicationInsight']._options = None
  _APPLICATIONMANAGER.methods_by_name['SnoozeApplicationInsight']._serialized_options = b'\202\323\344\223\0022\0320/v1/applications/{application=*}/insights/snooze'
  _APPLICATIONMANAGER.methods_by_name['GetApplicationMetadata']._options = None
  _APPLICATIONMANAGER.methods_by_name['GetApplicationMetadata']._serialized_options = b'\202\323\344\223\002+\022)/v1/applications/{application=*}/metadata'
  _APPLICATIONMANAGER.methods_by_name['SetApplicationMetadata']._options = None
  _APPLICATIONMANAGER.methods_by_name['SetApplicationMetadata']._serialized_options = b'\202\323\344\223\002.\")/v1/applications/{application=*}/metadata:\001*'
  _globals['_LISTAPPLICATIONSREQ']._serialized_start=497
  _globals['_LISTAPPLICATIONSREQ']._serialized_end=536
  _globals['_LISTAPPLICATIONSRESP']._serialized_start=538
  _globals['_LISTAPPLICATIONSRESP']._serialized_end=617
  _globals['_GETAPPLICATIONREQ']._serialized_start=619
  _globals['_GETAPPLICATIONREQ']._serialized_end=668
  _globals['_GETAPPLICATIONRESP']._serialized_start=670
  _globals['_GETAPPLICATIONRESP']._serialized_end=746
  _globals['_CONFIGUREAPPLICATIONREQ']._serialized_start=749
  _globals['_CONFIGUREAPPLICATIONREQ']._serialized_end=1015
  _globals['_CONFIGUREAPPLICATIONRESP']._serialized_start=1017
  _globals['_CONFIGUREAPPLICATIONRESP']._serialized_end=1086
  _globals['_VALIDATECONFIGUREAPPLICATIONRESP']._serialized_start=1089
  _globals['_VALIDATECONFIGUREAPPLICATIONRESP']._serialized_end=1314
  _globals['_GETAPPLICATIONCONFIGREQ']._serialized_start=1316
  _globals['_GETAPPLICATIONCONFIGREQ']._serialized_end=1388
  _globals['_GETAPPLICATIONCONFIGRESP']._serialized_start=1391
  _globals['_GETAPPLICATIONCONFIGRESP']._serialized_end=1557
  _globals['_DELETEAPPLICATIONREQ']._serialized_start=1559
  _globals['_DELETEAPPLICATIONREQ']._serialized_end=1611
  _globals['_DELETEAPPLICATIONRESP']._serialized_start=1613
  _globals['_DELETEAPPLICATIONRESP']._serialized_end=1636
  _globals['_GETAPPLICATIONMETRICSREQ']._serialized_start=1639
  _globals['_GETAPPLICATIONMETRICSREQ']._serialized_end=1799
  _globals['_GETAPPLICATIONMETRICSRESP']._serialized_start=1801
  _globals['_GETAPPLICATIONMETRICSRESP']._serialized_end=1893
  _globals['_GETAPPLICATIONINSIGHTSREQ']._serialized_start=1895
  _globals['_GETAPPLICATIONINSIGHTSREQ']._serialized_end=1952
  _globals['_GETAPPLICATIONINSIGHTSRESP']._serialized_start=1954
  _globals['_GETAPPLICATIONINSIGHTSRESP']._serialized_end=2028
  _globals['_SNOOZEAPPLICATIONINSIGHTREQ']._serialized_start=2031
  _globals['_SNOOZEAPPLICATIONINSIGHTREQ']._serialized_end=2198
  _globals['_SNOOZEAPPLICATIONINSIGHTRESP']._serialized_start=2200
  _globals['_SNOOZEAPPLICATIONINSIGHTRESP']._serialized_end=2230
  _globals['_GETAPPLICATIONMETADATAREQ']._serialized_start=2232
  _globals['_GETAPPLICATIONMETADATAREQ']._serialized_end=2289
  _globals['_GETAPPLICATIONMETADATARESP']._serialized_start=2291
  _globals['_GETAPPLICATIONMETADATARESP']._serialized_end=2384
  _globals['_SETAPPLICATIONMETADATAREQ']._serialized_start=2387
  _globals['_SETAPPLICATIONMETADATAREQ']._serialized_end=2519
  _globals['_SETAPPLICATIONMETADATARESP']._serialized_start=2521
  _globals['_SETAPPLICATIONMETADATARESP']._serialized_end=2549
  _globals['_APPLICATIONMANAGER']._serialized_start=2552
  _globals['_APPLICATIONMANAGER']._serialized_end=4406
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import prodvana.proto.prodvana.object.meta_pb2
import prodvana.proto.prodvana.repo.repo_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ReleaseStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReleaseStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReleaseStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_STATUS: _ReleaseStatus.ValueType  # 0
    PENDING: _ReleaseStatus.ValueType  # 1
    SUCCEEDED: _ReleaseStatus.ValueType  # 2
    FAILED: _ReleaseStatus.ValueType  # 3

class ReleaseStatus(_ReleaseStatus, metaclass=_ReleaseStatusEnumTypeWrapper): ...

UNKNOWN_STATUS: ReleaseStatus.ValueType  # 0
PENDING: ReleaseStatus.ValueType  # 1
SUCCEEDED: ReleaseStatus.ValueType  # 2
FAILED: ReleaseStatus.ValueType  # 3
global___ReleaseStatus = ReleaseStatus

class ReleaseConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DEPLOYMENT_SYSTEM_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    REPOSITORY_FIELD_NUMBER: builtins.int
    COMMIT_ID_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """must be unset on input"""
    deployment_system: builtins.str
    service: builtins.str
    release_channel: builtins.str
    application: builtins.str
    repository: builtins.str
    """e.g. github.com/foo/bar"""
    commit_id: builtins.str
    """commit hash"""
    user: builtins.str
    """if known"""
    def __init__(
        self,
        *,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        deployment_system: builtins.str = ...,
        service: builtins.str = ...,
        release_channel: builtins.str = ...,
        application: builtins.str = ...,
        repository: builtins.str = ...,
        commit_id: builtins.str = ...,
        user: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "commit_id", b"commit_id", "creation_timestamp", b"creation_timestamp", "deployment_system", b"deployment_system", "release_channel", b"release_channel", "repository", b"repository", "service", b"service", "user", b"user"]) -> None: ...

global___ReleaseConfig = ReleaseConfig

class ReleaseState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIMESTAMP_FIELD_NUMBER: builtins.int
    status: global___ReleaseStatus.ValueType
    @property
    def last_update_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        status: global___ReleaseStatus.ValueType = ...,
        last_update_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_update_timestamp", b"last_update_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_update_timestamp", b"last_update_timestamp", "status", b"status"]) -> None: ...

global___ReleaseState = ReleaseState

class ImpactAnalysisComparison(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEVANT_COMMITS_FIELD_NUMBER: builtins.int
    UNANALYZED_COMMITS_FIELD_NUMBER: builtins.int
    @property
    def relevant_commits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.repo.repo_pb2.Commit]:
        """commits likely to be impactful, prev_commit_id and new_commit_id have a merge base"""
    unanalyzed_commits: builtins.int
    def __init__(
        self,
        *,
        relevant_commits: collections.abc.Iterable[prodvana.proto.prodvana.repo.repo_pb2.Commit] | None = ...,
        unanalyzed_commits: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["relevant_commits", b"relevant_commits", "unanalyzed_commits", b"unanalyzed_commits"]) -> None: ...

global___ImpactAnalysisComparison = ImpactAnalysisComparison

class ReleaseComparison(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREV_FIELD_NUMBER: builtins.int
    PREV_REPOSITORY_FIELD_NUMBER: builtins.int
    NEW_REPOSITORY_FIELD_NUMBER: builtins.int
    PREV_COMMIT_ID_FIELD_NUMBER: builtins.int
    NEW_COMMIT_ID_FIELD_NUMBER: builtins.int
    IMPACT_ANALYSIS_FIELD_NUMBER: builtins.int
    TOTAL_COMMITS_FIELD_NUMBER: builtins.int
    @property
    def prev(self) -> prodvana.proto.prodvana.object.meta_pb2.ObjectMeta: ...
    prev_repository: builtins.str
    new_repository: builtins.str
    prev_commit_id: builtins.str
    new_commit_id: builtins.str
    @property
    def impact_analysis(self) -> global___ImpactAnalysisComparison: ...
    @property
    def total_commits(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """only set if the previous commit is set and is from the same repo, and the repo is linked to prodvana"""
    def __init__(
        self,
        *,
        prev: prodvana.proto.prodvana.object.meta_pb2.ObjectMeta | None = ...,
        prev_repository: builtins.str = ...,
        new_repository: builtins.str = ...,
        prev_commit_id: builtins.str = ...,
        new_commit_id: builtins.str = ...,
        impact_analysis: global___ImpactAnalysisComparison | None = ...,
        total_commits: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["impact_analysis", b"impact_analysis", "prev", b"prev", "total_commits", b"total_commits"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["impact_analysis", b"impact_analysis", "new_commit_id", b"new_commit_id", "new_repository", b"new_repository", "prev", b"prev", "prev_commit_id", b"prev_commit_id", "prev_repository", b"prev_repository", "total_commits", b"total_commits"]) -> None: ...

global___ReleaseComparison = ReleaseComparison

class Release(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    COMPARISON_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> prodvana.proto.prodvana.object.meta_pb2.ObjectMeta: ...
    @property
    def config(self) -> global___ReleaseConfig: ...
    @property
    def comparison(self) -> global___ReleaseComparison:
        """TODO(naphat) should this really be part of the proto here, or should it be a separate endpoint so we can request arbitrary comparison?"""
    @property
    def state(self) -> global___ReleaseState: ...
    def __init__(
        self,
        *,
        meta: prodvana.proto.prodvana.object.meta_pb2.ObjectMeta | None = ...,
        config: global___ReleaseConfig | None = ...,
        comparison: global___ReleaseComparison | None = ...,
        state: global___ReleaseState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["comparison", b"comparison", "config", b"config", "meta", b"meta", "state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comparison", b"comparison", "config", b"config", "meta", b"meta", "state", b"state"]) -> None: ...

global___Release = Release



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CanaryProgress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CANARY_WEIGHT_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    canary_weight: builtins.int
    """weight to advance canary to, percentage 0-100"""
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """duration to pause at this weight before advancing"""
    def __init__(
        self,
        *,
        canary_weight: builtins.int = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["canary_weight", b"canary_weight", "duration", b"duration"]) -> None: ...

global___CanaryProgress = CanaryProgress

class DeliveryConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CANARY_PROGRESS_FIELD_NUMBER: builtins.int
    ANALYSIS_TEMPLATES_FIELD_NUMBER: builtins.int
    @property
    def canary_progress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CanaryProgress]:
        """progression of canary as delivery occurs"""
    @property
    def analysis_templates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        canary_progress: collections.abc.Iterable[global___CanaryProgress] | None = ...,
        analysis_templates: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["analysis_templates", b"analysis_templates", "canary_progress", b"canary_progress"]) -> None: ...

global___DeliveryConfig = DeliveryConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/auth/auth_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.auth import auth_pb2 as prodvana_dot_auth_dot_auth__pb2
from prodvana.proto.prodvana.users import users_pb2 as prodvana_dot_users_dot_users__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n prodvana/auth/auth_manager.proto\x12\rprodvana.auth\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x18prodvana/auth/auth.proto\x1a\x1aprodvana/users/users.proto\"g\n\x0fGetTokenRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x14\n\x0credirect_url\x18\x02 \x01(\t\x12\x0f\n\x07\x66or_cli\x18\x03 \x01(\x08\x12\x1f\n\x17prodvana_only_admin_org\x18\x04 \x01(\x08\"&\n\x12GetAuthUrlResponse\x12\x10\n\x08\x61uth_url\x18\x01 \x01(\t\"\x8a\x01\n\x11GetAuthUrlRequest\x12\r\n\x05state\x18\x02 \x01(\t\x12\x0f\n\x07\x66or_cli\x18\x03 \x01(\x08\x12\x12\n\ninvitation\x18\x04 \x01(\t\x12\x1f\n\x17prodvana_only_admin_org\x18\x06 \x01(\x08J\x04\x08\x01\x10\x02J\x04\x08\x05\x10\x06R\x0credirect_urlR\x06no_org\"\x0c\n\nCliAuthReq\"\xe2\x01\n\x0b\x43liAuthResp\x12<\n\x0buser_prompt\x18\x01 \x01(\x0b\x32%.prodvana.auth.CliAuthResp.UserPromptH\x00\x12)\n\x05token\x18\x02 \x01(\x0b\x32\x18.prodvana.auth.AuthTokenH\x00\x1a\\\n\nUserPrompt\x12\x11\n\tuser_code\x18\x01 \x01(\t\x12\x18\n\x10verification_uri\x18\x02 \x01(\t\x12!\n\x19verification_uri_complete\x18\x03 \x01(\tB\x0c\n\nresp_oneof\"l\n\x0fRefreshTokenReq\x12\'\n\x05token\x18\x01 \x01(\x0b\x32\x18.prodvana.auth.AuthToken\x12\x0f\n\x07\x66or_cli\x18\x02 \x01(\x08\x12\x1f\n\x17prodvana_only_admin_org\x18\x03 \x01(\x08\"_\n\x10GetAuthTokenResp\x12\'\n\x05token\x18\x01 \x01(\x0b\x32\x18.prodvana.auth.AuthToken\x12\"\n\x04user\x18\x02 \x01(\x0b\x32\x14.prodvana.users.User\"\x07\n\x05\x45mpty\"p\n\x14\x43reateOrgApiTokenReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x35\n\x11\x65xpires_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"U\n\x15\x43reateOrgApiTokenResp\x12\x11\n\tapi_token\x18\x01 \x01(\t\x12)\n\x04info\x18\x02 \x01(\x0b\x32\x1b.prodvana.auth.ApiTokenInfo\"$\n\x14\x44\x65leteOrgApiTokenReq\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x17\n\x15\x44\x65leteOrgApiTokenResp\"\x15\n\x13ListOrgApiTokensReq\"C\n\x14ListOrgApiTokensResp\x12+\n\x06tokens\x18\x01 \x03(\x0b\x32\x1b.prodvana.auth.ApiTokenInfo2\xab\x03\n\x0b\x41uthManager\x12k\n\x0cGetAuthToken\x12\x1e.prodvana.auth.GetTokenRequest\x1a\x1f.prodvana.auth.GetAuthTokenResp\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/auth/get_token\x12p\n\nGetAuthUrl\x12 .prodvana.auth.GetAuthUrlRequest\x1a!.prodvana.auth.GetAuthUrlResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/auth/get_auth_url\x12w\n\x0cRefreshToken\x12\x1e.prodvana.auth.RefreshTokenReq\x1a\x1f.prodvana.auth.GetAuthTokenResp\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/auth/refresh_auth_token:\x01*\x12\x44\n\x07\x43liAuth\x12\x19.prodvana.auth.CliAuthReq\x1a\x1a.prodvana.auth.CliAuthResp\"\x00\x30\x01\x32i\n\x12\x41uthSessionManager\x12S\n\x05\x43heck\x12\x14.prodvana.auth.Empty\x1a\x14.prodvana.auth.Empty\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/auth/session/check2\xa2\x04\n\x0f\x41piTokenManager\x12y\n\x11\x43reateOrgApiToken\x12\x14.prodvana.auth.Empty\x1a$.prodvana.auth.CreateOrgApiTokenResp\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/auth/api/create_org_token:\x01*\x12\x8a\x01\n\x12\x43reateOrgApiToken2\x12#.prodvana.auth.CreateOrgApiTokenReq\x1a$.prodvana.auth.CreateOrgApiTokenResp\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/auth/api/org_tokens/create:\x01*\x12\x88\x01\n\x11\x44\x65leteOrgApiToken\x12#.prodvana.auth.DeleteOrgApiTokenReq\x1a$.prodvana.auth.DeleteOrgApiTokenResp\"(\x82\xd3\xe4\x93\x02\"* /v1/auth/api/org_tokens/{name=*}\x12|\n\x10ListOrgApiTokens\x12\".prodvana.auth.ListOrgApiTokensReq\x1a#.prodvana.auth.ListOrgApiTokensResp\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/auth/api/org_tokensBIZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.auth.auth_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/auth'
  _AUTHMANAGER.methods_by_name['GetAuthToken']._options = None
  _AUTHMANAGER.methods_by_name['GetAuthToken']._serialized_options = b'\202\323\344\223\002\024\022\022/v1/auth/get_token'
  _AUTHMANAGER.methods_by_name['GetAuthUrl']._options = None
  _AUTHMANAGER.methods_by_name['GetAuthUrl']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/auth/get_auth_url'
  _AUTHMANAGER.methods_by_name['RefreshToken']._options = None
  _AUTHMANAGER.methods_by_name['RefreshToken']._serialized_options = b'\202\323\344\223\002 \"\033/v1/auth/refresh_auth_token:\001*'
  _AUTHSESSIONMANAGER.methods_by_name['Check']._options = None
  _AUTHSESSIONMANAGER.methods_by_name['Check']._serialized_options = b'\202\323\344\223\002\030\022\026/v1/auth/session/check'
  _APITOKENMANAGER.methods_by_name['CreateOrgApiToken']._options = None
  _APITOKENMANAGER.methods_by_name['CreateOrgApiToken']._serialized_options = b'\202\323\344\223\002\"\"\035/v1/auth/api/create_org_token:\001*'
  _APITOKENMANAGER.methods_by_name['CreateOrgApiToken2']._options = None
  _APITOKENMANAGER.methods_by_name['CreateOrgApiToken2']._serialized_options = b'\202\323\344\223\002#\"\036/v1/auth/api/org_tokens/create:\001*'
  _APITOKENMANAGER.methods_by_name['DeleteOrgApiToken']._options = None
  _APITOKENMANAGER.methods_by_name['DeleteOrgApiToken']._serialized_options = b'\202\323\344\223\002\"* /v1/auth/api/org_tokens/{name=*}'
  _APITOKENMANAGER.methods_by_name['ListOrgApiTokens']._options = None
  _APITOKENMANAGER.methods_by_name['ListOrgApiTokens']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/auth/api/org_tokens'
  _globals['_GETTOKENREQUEST']._serialized_start=168
  _globals['_GETTOKENREQUEST']._serialized_end=271
  _globals['_GETAUTHURLRESPONSE']._serialized_start=273
  _globals['_GETAUTHURLRESPONSE']._serialized_end=311
  _globals['_GETAUTHURLREQUEST']._serialized_start=314
  _globals['_GETAUTHURLREQUEST']._serialized_end=452
  _globals['_CLIAUTHREQ']._serialized_start=454
  _globals['_CLIAUTHREQ']._serialized_end=466
  _globals['_CLIAUTHRESP']._serialized_start=469
  _globals['_CLIAUTHRESP']._serialized_end=695
  _globals['_CLIAUTHRESP_USERPROMPT']._serialized_start=589
  _globals['_CLIAUTHRESP_USERPROMPT']._serialized_end=681
  _globals['_REFRESHTOKENREQ']._serialized_start=697
  _globals['_REFRESHTOKENREQ']._serialized_end=805
  _globals['_GETAUTHTOKENRESP']._serialized_start=807
  _globals['_GETAUTHTOKENRESP']._serialized_end=902
  _globals['_EMPTY']._serialized_start=904
  _globals['_EMPTY']._serialized_end=911
  _globals['_CREATEORGAPITOKENREQ']._serialized_start=913
  _globals['_CREATEORGAPITOKENREQ']._serialized_end=1025
  _globals['_CREATEORGAPITOKENRESP']._serialized_start=1027
  _globals['_CREATEORGAPITOKENRESP']._serialized_end=1112
  _globals['_DELETEORGAPITOKENREQ']._serialized_start=1114
  _globals['_DELETEORGAPITOKENREQ']._serialized_end=1150
  _globals['_DELETEORGAPITOKENRESP']._serialized_start=1152
  _globals['_DELETEORGAPITOKENRESP']._serialized_end=1175
  _globals['_LISTORGAPITOKENSREQ']._serialized_start=1177
  _globals['_LISTORGAPITOKENSREQ']._serialized_end=1198
  _globals['_LISTORGAPITOKENSRESP']._serialized_start=1200
  _globals['_LISTORGAPITOKENSRESP']._serialized_end=1267
  _globals['_AUTHMANAGER']._serialized_start=1270
  _globals['_AUTHMANAGER']._serialized_end=1697
  _globals['_AUTHSESSIONMANAGER']._serialized_start=1699
  _globals['_AUTHSESSIONMANAGER']._serialized_end=1804
  _globals['_APITOKENMANAGER']._serialized_start=1807
  _globals['_APITOKENMANAGER']._serialized_end=2353
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/repo/repo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.impact_analysis import impact_analysis_pb2 as prodvana_dot_impact__analysis_dot_impact__analysis__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18prodvana/repo/repo.proto\x12\rprodvana.repo\x1a.prodvana/impact_analysis/impact_analysis.proto\"#\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"\xa7\x01\n\x06\x43ommit\x12\x11\n\tcommit_id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12#\n\x06\x61uthor\x18\x04 \x01(\x0b\x32\x13.prodvana.repo.User\x12G\n\x0fimpact_analysis\x18\x05 \x01(\x0b\x32..prodvana.impact_analysis.ImpactAnalysisResult\"1\n\x0b\x46uzzyCommit\x12\x12\n\ncommit_ish\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\tBIZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/repob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.repo.repo_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/repo'
  _globals['_USER']._serialized_start=91
  _globals['_USER']._serialized_end=126
  _globals['_COMMIT']._serialized_start=129
  _globals['_COMMIT']._serialized_end=296
  _globals['_FUZZYCOMMIT']._serialized_start=298
  _globals['_FUZZYCOMMIT']._serialized_end=347
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import prodvana.proto.prodvana.application.application_config_pb2
import prodvana.proto.prodvana.application.user_metadata_pb2
import prodvana.proto.prodvana.object.meta_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ApplicationState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ApplicationState = ApplicationState

class Application(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    USER_METADATA_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> prodvana.proto.prodvana.object.meta_pb2.ObjectMeta: ...
    @property
    def config(self) -> prodvana.proto.prodvana.application.application_config_pb2.ApplicationConfig: ...
    @property
    def state(self) -> global___ApplicationState: ...
    @property
    def user_metadata(self) -> prodvana.proto.prodvana.application.user_metadata_pb2.ApplicationUserMetadata: ...
    def __init__(
        self,
        *,
        meta: prodvana.proto.prodvana.object.meta_pb2.ObjectMeta | None = ...,
        config: prodvana.proto.prodvana.application.application_config_pb2.ApplicationConfig | None = ...,
        state: global___ApplicationState | None = ...,
        user_metadata: prodvana.proto.prodvana.application.user_metadata_pb2.ApplicationUserMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "meta", b"meta", "state", b"state", "user_metadata", b"user_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "meta", b"meta", "state", b"state", "user_metadata", b"user_metadata"]) -> None: ...

global___Application = Application



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.events.events_pb2
import prodvana.proto.prodvana.events.types_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ServiceLookup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service"]) -> None: ...

global___ServiceLookup = ServiceLookup

class ReleaseChannelLookup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    application: builtins.str
    release_channel: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        release_channel: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "release_channel", b"release_channel"]) -> None: ...

global___ReleaseChannelLookup = ReleaseChannelLookup

class Lookup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    root_desired_state_id: builtins.str
    desired_state_id: builtins.str
    @property
    def service(self) -> global___ServiceLookup: ...
    @property
    def release_channel(self) -> global___ReleaseChannelLookup: ...
    def __init__(
        self,
        *,
        root_desired_state_id: builtins.str = ...,
        desired_state_id: builtins.str = ...,
        service: global___ServiceLookup | None = ...,
        release_channel: global___ReleaseChannelLookup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id", "lookup_oneof", b"lookup_oneof", "release_channel", b"release_channel", "root_desired_state_id", b"root_desired_state_id", "service", b"service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id", "lookup_oneof", b"lookup_oneof", "release_channel", b"release_channel", "root_desired_state_id", b"root_desired_state_id", "service", b"service"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["lookup_oneof", b"lookup_oneof"]) -> typing_extensions.Literal["root_desired_state_id", "desired_state_id", "service", "release_channel"] | None: ...

global___Lookup = Lookup

class GetEventsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOOKUPS_FIELD_NUMBER: builtins.int
    TYPES_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    ORDER_BY_ASC_TIMESTAMP_FIELD_NUMBER: builtins.int
    USEOR_FIELD_NUMBER: builtins.int
    BEFORE_TIMESTAMP_FIELD_NUMBER: builtins.int
    AFTER_TIMESTAMP_FIELD_NUMBER: builtins.int
    @property
    def lookups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Lookup]: ...
    @property
    def types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[prodvana.proto.prodvana.events.types_pb2.EventType.ValueType]:
        """empty means to include all types"""
    page_token: builtins.str
    page_size: builtins.int
    order_by_asc_timestamp: builtins.bool
    useOr: builtins.bool
    @property
    def before_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def after_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        lookups: collections.abc.Iterable[global___Lookup] | None = ...,
        types: collections.abc.Iterable[prodvana.proto.prodvana.events.types_pb2.EventType.ValueType] | None = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
        order_by_asc_timestamp: builtins.bool = ...,
        useOr: builtins.bool = ...,
        before_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        after_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["after_timestamp", b"after_timestamp", "before_timestamp", b"before_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["after_timestamp", b"after_timestamp", "before_timestamp", b"before_timestamp", "lookups", b"lookups", "order_by_asc_timestamp", b"order_by_asc_timestamp", "page_size", b"page_size", "page_token", b"page_token", "types", b"types", "useOr", b"useOr"]) -> None: ...

global___GetEventsReq = GetEventsReq

class GetEventsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.events.events_pb2.Event]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        events: collections.abc.Iterable[prodvana.proto.prodvana.events.events_pb2.Event] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["events", b"events", "next_page_token", b"next_page_token"]) -> None: ...

global___GetEventsResp = GetEventsResp
